#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class PaymentApplyResponseDTO(object):

    def __init__(self):
        self._apply_relative_id = None
        self._arrangement_no = None
        self._bill_type = None
        self._customer_name = None
        self._guarantee_noney = None
        self._inst_id = None
        self._inst_name = None
        self._invaccept_receivable_amt = None
        self._invaccept_relevant_amt = None
        self._invoice_receivable_amount = None
        self._invoice_received_amount = None
        self._issued_paid_amount = None
        self._kp_no = None
        self._paid_amount = None
        self._pay_contract_desc = None
        self._pay_contract_item_no = None
        self._payable_amount = None
        self._rt_no = None
        self._settle_status = None
        self._source = None
        self._stage = None
        self._tax_account_no = None
        self._tax_address = None
        self._tax_amount = None
        self._tax_bank_name = None
        self._tax_invoice_title = None
        self._tax_phone_no = None
        self._tax_rate = None
        self._tax_tax_no = None
        self._tax_type = None
        self._tax_type_desc = None
        self._to_pay_amount = None
        self._un_invoice_received_amount = None
        self._wroteoff_amount = None

    @property
    def apply_relative_id(self):
        return self._apply_relative_id

    @apply_relative_id.setter
    def apply_relative_id(self, value):
        self._apply_relative_id = value
    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def bill_type(self):
        return self._bill_type

    @bill_type.setter
    def bill_type(self, value):
        self._bill_type = value
    @property
    def customer_name(self):
        return self._customer_name

    @customer_name.setter
    def customer_name(self, value):
        self._customer_name = value
    @property
    def guarantee_noney(self):
        return self._guarantee_noney

    @guarantee_noney.setter
    def guarantee_noney(self, value):
        self._guarantee_noney = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def invaccept_receivable_amt(self):
        return self._invaccept_receivable_amt

    @invaccept_receivable_amt.setter
    def invaccept_receivable_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invaccept_receivable_amt = value
        else:
            self._invaccept_receivable_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invaccept_relevant_amt(self):
        return self._invaccept_relevant_amt

    @invaccept_relevant_amt.setter
    def invaccept_relevant_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invaccept_relevant_amt = value
        else:
            self._invaccept_relevant_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_receivable_amount(self):
        return self._invoice_receivable_amount

    @invoice_receivable_amount.setter
    def invoice_receivable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_receivable_amount = value
        else:
            self._invoice_receivable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_received_amount(self):
        return self._invoice_received_amount

    @invoice_received_amount.setter
    def invoice_received_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_received_amount = value
        else:
            self._invoice_received_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def issued_paid_amount(self):
        return self._issued_paid_amount

    @issued_paid_amount.setter
    def issued_paid_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._issued_paid_amount = value
        else:
            self._issued_paid_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def kp_no(self):
        return self._kp_no

    @kp_no.setter
    def kp_no(self, value):
        self._kp_no = value
    @property
    def paid_amount(self):
        return self._paid_amount

    @paid_amount.setter
    def paid_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._paid_amount = value
        else:
            self._paid_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def pay_contract_desc(self):
        return self._pay_contract_desc

    @pay_contract_desc.setter
    def pay_contract_desc(self, value):
        self._pay_contract_desc = value
    @property
    def pay_contract_item_no(self):
        return self._pay_contract_item_no

    @pay_contract_item_no.setter
    def pay_contract_item_no(self, value):
        self._pay_contract_item_no = value
    @property
    def payable_amount(self):
        return self._payable_amount

    @payable_amount.setter
    def payable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._payable_amount = value
        else:
            self._payable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def rt_no(self):
        return self._rt_no

    @rt_no.setter
    def rt_no(self, value):
        self._rt_no = value
    @property
    def settle_status(self):
        return self._settle_status

    @settle_status.setter
    def settle_status(self, value):
        self._settle_status = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def stage(self):
        return self._stage

    @stage.setter
    def stage(self, value):
        self._stage = value
    @property
    def tax_account_no(self):
        return self._tax_account_no

    @tax_account_no.setter
    def tax_account_no(self, value):
        self._tax_account_no = value
    @property
    def tax_address(self):
        return self._tax_address

    @tax_address.setter
    def tax_address(self, value):
        self._tax_address = value
    @property
    def tax_amount(self):
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._tax_amount = value
        else:
            self._tax_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def tax_bank_name(self):
        return self._tax_bank_name

    @tax_bank_name.setter
    def tax_bank_name(self, value):
        self._tax_bank_name = value
    @property
    def tax_invoice_title(self):
        return self._tax_invoice_title

    @tax_invoice_title.setter
    def tax_invoice_title(self, value):
        self._tax_invoice_title = value
    @property
    def tax_phone_no(self):
        return self._tax_phone_no

    @tax_phone_no.setter
    def tax_phone_no(self, value):
        self._tax_phone_no = value
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value
    @property
    def tax_tax_no(self):
        return self._tax_tax_no

    @tax_tax_no.setter
    def tax_tax_no(self, value):
        self._tax_tax_no = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value
    @property
    def tax_type_desc(self):
        return self._tax_type_desc

    @tax_type_desc.setter
    def tax_type_desc(self, value):
        self._tax_type_desc = value
    @property
    def to_pay_amount(self):
        return self._to_pay_amount

    @to_pay_amount.setter
    def to_pay_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._to_pay_amount = value
        else:
            self._to_pay_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def un_invoice_received_amount(self):
        return self._un_invoice_received_amount

    @un_invoice_received_amount.setter
    def un_invoice_received_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._un_invoice_received_amount = value
        else:
            self._un_invoice_received_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def wroteoff_amount(self):
        return self._wroteoff_amount

    @wroteoff_amount.setter
    def wroteoff_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._wroteoff_amount = value
        else:
            self._wroteoff_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_relative_id:
            if hasattr(self.apply_relative_id, 'to_alipay_dict'):
                params['apply_relative_id'] = self.apply_relative_id.to_alipay_dict()
            else:
                params['apply_relative_id'] = self.apply_relative_id
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.bill_type:
            if hasattr(self.bill_type, 'to_alipay_dict'):
                params['bill_type'] = self.bill_type.to_alipay_dict()
            else:
                params['bill_type'] = self.bill_type
        if self.customer_name:
            if hasattr(self.customer_name, 'to_alipay_dict'):
                params['customer_name'] = self.customer_name.to_alipay_dict()
            else:
                params['customer_name'] = self.customer_name
        if self.guarantee_noney:
            if hasattr(self.guarantee_noney, 'to_alipay_dict'):
                params['guarantee_noney'] = self.guarantee_noney.to_alipay_dict()
            else:
                params['guarantee_noney'] = self.guarantee_noney
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.invaccept_receivable_amt:
            if hasattr(self.invaccept_receivable_amt, 'to_alipay_dict'):
                params['invaccept_receivable_amt'] = self.invaccept_receivable_amt.to_alipay_dict()
            else:
                params['invaccept_receivable_amt'] = self.invaccept_receivable_amt
        if self.invaccept_relevant_amt:
            if hasattr(self.invaccept_relevant_amt, 'to_alipay_dict'):
                params['invaccept_relevant_amt'] = self.invaccept_relevant_amt.to_alipay_dict()
            else:
                params['invaccept_relevant_amt'] = self.invaccept_relevant_amt
        if self.invoice_receivable_amount:
            if hasattr(self.invoice_receivable_amount, 'to_alipay_dict'):
                params['invoice_receivable_amount'] = self.invoice_receivable_amount.to_alipay_dict()
            else:
                params['invoice_receivable_amount'] = self.invoice_receivable_amount
        if self.invoice_received_amount:
            if hasattr(self.invoice_received_amount, 'to_alipay_dict'):
                params['invoice_received_amount'] = self.invoice_received_amount.to_alipay_dict()
            else:
                params['invoice_received_amount'] = self.invoice_received_amount
        if self.issued_paid_amount:
            if hasattr(self.issued_paid_amount, 'to_alipay_dict'):
                params['issued_paid_amount'] = self.issued_paid_amount.to_alipay_dict()
            else:
                params['issued_paid_amount'] = self.issued_paid_amount
        if self.kp_no:
            if hasattr(self.kp_no, 'to_alipay_dict'):
                params['kp_no'] = self.kp_no.to_alipay_dict()
            else:
                params['kp_no'] = self.kp_no
        if self.paid_amount:
            if hasattr(self.paid_amount, 'to_alipay_dict'):
                params['paid_amount'] = self.paid_amount.to_alipay_dict()
            else:
                params['paid_amount'] = self.paid_amount
        if self.pay_contract_desc:
            if hasattr(self.pay_contract_desc, 'to_alipay_dict'):
                params['pay_contract_desc'] = self.pay_contract_desc.to_alipay_dict()
            else:
                params['pay_contract_desc'] = self.pay_contract_desc
        if self.pay_contract_item_no:
            if hasattr(self.pay_contract_item_no, 'to_alipay_dict'):
                params['pay_contract_item_no'] = self.pay_contract_item_no.to_alipay_dict()
            else:
                params['pay_contract_item_no'] = self.pay_contract_item_no
        if self.payable_amount:
            if hasattr(self.payable_amount, 'to_alipay_dict'):
                params['payable_amount'] = self.payable_amount.to_alipay_dict()
            else:
                params['payable_amount'] = self.payable_amount
        if self.rt_no:
            if hasattr(self.rt_no, 'to_alipay_dict'):
                params['rt_no'] = self.rt_no.to_alipay_dict()
            else:
                params['rt_no'] = self.rt_no
        if self.settle_status:
            if hasattr(self.settle_status, 'to_alipay_dict'):
                params['settle_status'] = self.settle_status.to_alipay_dict()
            else:
                params['settle_status'] = self.settle_status
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.stage:
            if hasattr(self.stage, 'to_alipay_dict'):
                params['stage'] = self.stage.to_alipay_dict()
            else:
                params['stage'] = self.stage
        if self.tax_account_no:
            if hasattr(self.tax_account_no, 'to_alipay_dict'):
                params['tax_account_no'] = self.tax_account_no.to_alipay_dict()
            else:
                params['tax_account_no'] = self.tax_account_no
        if self.tax_address:
            if hasattr(self.tax_address, 'to_alipay_dict'):
                params['tax_address'] = self.tax_address.to_alipay_dict()
            else:
                params['tax_address'] = self.tax_address
        if self.tax_amount:
            if hasattr(self.tax_amount, 'to_alipay_dict'):
                params['tax_amount'] = self.tax_amount.to_alipay_dict()
            else:
                params['tax_amount'] = self.tax_amount
        if self.tax_bank_name:
            if hasattr(self.tax_bank_name, 'to_alipay_dict'):
                params['tax_bank_name'] = self.tax_bank_name.to_alipay_dict()
            else:
                params['tax_bank_name'] = self.tax_bank_name
        if self.tax_invoice_title:
            if hasattr(self.tax_invoice_title, 'to_alipay_dict'):
                params['tax_invoice_title'] = self.tax_invoice_title.to_alipay_dict()
            else:
                params['tax_invoice_title'] = self.tax_invoice_title
        if self.tax_phone_no:
            if hasattr(self.tax_phone_no, 'to_alipay_dict'):
                params['tax_phone_no'] = self.tax_phone_no.to_alipay_dict()
            else:
                params['tax_phone_no'] = self.tax_phone_no
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        if self.tax_tax_no:
            if hasattr(self.tax_tax_no, 'to_alipay_dict'):
                params['tax_tax_no'] = self.tax_tax_no.to_alipay_dict()
            else:
                params['tax_tax_no'] = self.tax_tax_no
        if self.tax_type:
            if hasattr(self.tax_type, 'to_alipay_dict'):
                params['tax_type'] = self.tax_type.to_alipay_dict()
            else:
                params['tax_type'] = self.tax_type
        if self.tax_type_desc:
            if hasattr(self.tax_type_desc, 'to_alipay_dict'):
                params['tax_type_desc'] = self.tax_type_desc.to_alipay_dict()
            else:
                params['tax_type_desc'] = self.tax_type_desc
        if self.to_pay_amount:
            if hasattr(self.to_pay_amount, 'to_alipay_dict'):
                params['to_pay_amount'] = self.to_pay_amount.to_alipay_dict()
            else:
                params['to_pay_amount'] = self.to_pay_amount
        if self.un_invoice_received_amount:
            if hasattr(self.un_invoice_received_amount, 'to_alipay_dict'):
                params['un_invoice_received_amount'] = self.un_invoice_received_amount.to_alipay_dict()
            else:
                params['un_invoice_received_amount'] = self.un_invoice_received_amount
        if self.wroteoff_amount:
            if hasattr(self.wroteoff_amount, 'to_alipay_dict'):
                params['wroteoff_amount'] = self.wroteoff_amount.to_alipay_dict()
            else:
                params['wroteoff_amount'] = self.wroteoff_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentApplyResponseDTO()
        if 'apply_relative_id' in d:
            o.apply_relative_id = d['apply_relative_id']
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'bill_type' in d:
            o.bill_type = d['bill_type']
        if 'customer_name' in d:
            o.customer_name = d['customer_name']
        if 'guarantee_noney' in d:
            o.guarantee_noney = d['guarantee_noney']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'invaccept_receivable_amt' in d:
            o.invaccept_receivable_amt = d['invaccept_receivable_amt']
        if 'invaccept_relevant_amt' in d:
            o.invaccept_relevant_amt = d['invaccept_relevant_amt']
        if 'invoice_receivable_amount' in d:
            o.invoice_receivable_amount = d['invoice_receivable_amount']
        if 'invoice_received_amount' in d:
            o.invoice_received_amount = d['invoice_received_amount']
        if 'issued_paid_amount' in d:
            o.issued_paid_amount = d['issued_paid_amount']
        if 'kp_no' in d:
            o.kp_no = d['kp_no']
        if 'paid_amount' in d:
            o.paid_amount = d['paid_amount']
        if 'pay_contract_desc' in d:
            o.pay_contract_desc = d['pay_contract_desc']
        if 'pay_contract_item_no' in d:
            o.pay_contract_item_no = d['pay_contract_item_no']
        if 'payable_amount' in d:
            o.payable_amount = d['payable_amount']
        if 'rt_no' in d:
            o.rt_no = d['rt_no']
        if 'settle_status' in d:
            o.settle_status = d['settle_status']
        if 'source' in d:
            o.source = d['source']
        if 'stage' in d:
            o.stage = d['stage']
        if 'tax_account_no' in d:
            o.tax_account_no = d['tax_account_no']
        if 'tax_address' in d:
            o.tax_address = d['tax_address']
        if 'tax_amount' in d:
            o.tax_amount = d['tax_amount']
        if 'tax_bank_name' in d:
            o.tax_bank_name = d['tax_bank_name']
        if 'tax_invoice_title' in d:
            o.tax_invoice_title = d['tax_invoice_title']
        if 'tax_phone_no' in d:
            o.tax_phone_no = d['tax_phone_no']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        if 'tax_tax_no' in d:
            o.tax_tax_no = d['tax_tax_no']
        if 'tax_type' in d:
            o.tax_type = d['tax_type']
        if 'tax_type_desc' in d:
            o.tax_type_desc = d['tax_type_desc']
        if 'to_pay_amount' in d:
            o.to_pay_amount = d['to_pay_amount']
        if 'un_invoice_received_amount' in d:
            o.un_invoice_received_amount = d['un_invoice_received_amount']
        if 'wroteoff_amount' in d:
            o.wroteoff_amount = d['wroteoff_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FundLimit(object):

    def __init__(self):
        self._limit_type = None
        self._limit_value = None

    @property
    def limit_type(self):
        return self._limit_type

    @limit_type.setter
    def limit_type(self, value):
        self._limit_type = value
    @property
    def limit_value(self):
        return self._limit_value

    @limit_value.setter
    def limit_value(self, value):
        self._limit_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.limit_type:
            if hasattr(self.limit_type, 'to_alipay_dict'):
                params['limit_type'] = self.limit_type.to_alipay_dict()
            else:
                params['limit_type'] = self.limit_type
        if self.limit_value:
            if hasattr(self.limit_value, 'to_alipay_dict'):
                params['limit_value'] = self.limit_value.to_alipay_dict()
            else:
                params['limit_value'] = self.limit_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundLimit()
        if 'limit_type' in d:
            o.limit_type = d['limit_type']
        if 'limit_value' in d:
            o.limit_value = d['limit_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CrowdSelectTagValuesOpenRequest(object):

    def __init__(self):
        self._tag_id = None
        self._tag_option_category_id = None
        self._values = None

    @property
    def tag_id(self):
        return self._tag_id

    @tag_id.setter
    def tag_id(self, value):
        self._tag_id = value
    @property
    def tag_option_category_id(self):
        return self._tag_option_category_id

    @tag_option_category_id.setter
    def tag_option_category_id(self, value):
        self._tag_option_category_id = value
    @property
    def values(self):
        return self._values

    @values.setter
    def values(self, value):
        self._values = value


    def to_alipay_dict(self):
        params = dict()
        if self.tag_id:
            if hasattr(self.tag_id, 'to_alipay_dict'):
                params['tag_id'] = self.tag_id.to_alipay_dict()
            else:
                params['tag_id'] = self.tag_id
        if self.tag_option_category_id:
            if hasattr(self.tag_option_category_id, 'to_alipay_dict'):
                params['tag_option_category_id'] = self.tag_option_category_id.to_alipay_dict()
            else:
                params['tag_option_category_id'] = self.tag_option_category_id
        if self.values:
            if hasattr(self.values, 'to_alipay_dict'):
                params['values'] = self.values.to_alipay_dict()
            else:
                params['values'] = self.values
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CrowdSelectTagValuesOpenRequest()
        if 'tag_id' in d:
            o.tag_id = d['tag_id']
        if 'tag_option_category_id' in d:
            o.tag_option_category_id = d['tag_option_category_id']
        if 'values' in d:
            o.values = d['values']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AntdataassetsOdpsColumn import AntdataassetsOdpsColumn


class AlipayDataDataserviceAntdataassetsOdpscolumnQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAntdataassetsOdpscolumnQueryResponse, self).__init__()
        self._odps_columns = None

    @property
    def odps_columns(self):
        return self._odps_columns

    @odps_columns.setter
    def odps_columns(self, value):
        if isinstance(value, list):
            self._odps_columns = list()
            for i in value:
                if isinstance(i, AntdataassetsOdpsColumn):
                    self._odps_columns.append(i)
                else:
                    self._odps_columns.append(AntdataassetsOdpsColumn.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAntdataassetsOdpscolumnQueryResponse, self).parse_response_content(response_content)
        if 'odps_columns' in response:
            self.odps_columns = response['odps_columns']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScheduleWorkItem(object):

    def __init__(self):
        self._all_miles = None
        self._all_trip_cnt = None
        self._chain_num = None
        self._invalid_miles = None
        self._invalid_trip_cnt = None
        self._line_id = None
        self._opt_type = None
        self._shift_id = None
        self._trip_chain = None
        self._valid_miles = None
        self._valid_trip_cnt = None
        self._wait_time = None
        self._work_endtime = None
        self._work_id = None
        self._work_starttime = None
        self._work_time = None

    @property
    def all_miles(self):
        return self._all_miles

    @all_miles.setter
    def all_miles(self, value):
        self._all_miles = value
    @property
    def all_trip_cnt(self):
        return self._all_trip_cnt

    @all_trip_cnt.setter
    def all_trip_cnt(self, value):
        self._all_trip_cnt = value
    @property
    def chain_num(self):
        return self._chain_num

    @chain_num.setter
    def chain_num(self, value):
        self._chain_num = value
    @property
    def invalid_miles(self):
        return self._invalid_miles

    @invalid_miles.setter
    def invalid_miles(self, value):
        self._invalid_miles = value
    @property
    def invalid_trip_cnt(self):
        return self._invalid_trip_cnt

    @invalid_trip_cnt.setter
    def invalid_trip_cnt(self, value):
        self._invalid_trip_cnt = value
    @property
    def line_id(self):
        return self._line_id

    @line_id.setter
    def line_id(self, value):
        self._line_id = value
    @property
    def opt_type(self):
        return self._opt_type

    @opt_type.setter
    def opt_type(self, value):
        self._opt_type = value
    @property
    def shift_id(self):
        return self._shift_id

    @shift_id.setter
    def shift_id(self, value):
        self._shift_id = value
    @property
    def trip_chain(self):
        return self._trip_chain

    @trip_chain.setter
    def trip_chain(self, value):
        self._trip_chain = value
    @property
    def valid_miles(self):
        return self._valid_miles

    @valid_miles.setter
    def valid_miles(self, value):
        self._valid_miles = value
    @property
    def valid_trip_cnt(self):
        return self._valid_trip_cnt

    @valid_trip_cnt.setter
    def valid_trip_cnt(self, value):
        self._valid_trip_cnt = value
    @property
    def wait_time(self):
        return self._wait_time

    @wait_time.setter
    def wait_time(self, value):
        self._wait_time = value
    @property
    def work_endtime(self):
        return self._work_endtime

    @work_endtime.setter
    def work_endtime(self, value):
        self._work_endtime = value
    @property
    def work_id(self):
        return self._work_id

    @work_id.setter
    def work_id(self, value):
        self._work_id = value
    @property
    def work_starttime(self):
        return self._work_starttime

    @work_starttime.setter
    def work_starttime(self, value):
        self._work_starttime = value
    @property
    def work_time(self):
        return self._work_time

    @work_time.setter
    def work_time(self, value):
        self._work_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.all_miles:
            if hasattr(self.all_miles, 'to_alipay_dict'):
                params['all_miles'] = self.all_miles.to_alipay_dict()
            else:
                params['all_miles'] = self.all_miles
        if self.all_trip_cnt:
            if hasattr(self.all_trip_cnt, 'to_alipay_dict'):
                params['all_trip_cnt'] = self.all_trip_cnt.to_alipay_dict()
            else:
                params['all_trip_cnt'] = self.all_trip_cnt
        if self.chain_num:
            if hasattr(self.chain_num, 'to_alipay_dict'):
                params['chain_num'] = self.chain_num.to_alipay_dict()
            else:
                params['chain_num'] = self.chain_num
        if self.invalid_miles:
            if hasattr(self.invalid_miles, 'to_alipay_dict'):
                params['invalid_miles'] = self.invalid_miles.to_alipay_dict()
            else:
                params['invalid_miles'] = self.invalid_miles
        if self.invalid_trip_cnt:
            if hasattr(self.invalid_trip_cnt, 'to_alipay_dict'):
                params['invalid_trip_cnt'] = self.invalid_trip_cnt.to_alipay_dict()
            else:
                params['invalid_trip_cnt'] = self.invalid_trip_cnt
        if self.line_id:
            if hasattr(self.line_id, 'to_alipay_dict'):
                params['line_id'] = self.line_id.to_alipay_dict()
            else:
                params['line_id'] = self.line_id
        if self.opt_type:
            if hasattr(self.opt_type, 'to_alipay_dict'):
                params['opt_type'] = self.opt_type.to_alipay_dict()
            else:
                params['opt_type'] = self.opt_type
        if self.shift_id:
            if hasattr(self.shift_id, 'to_alipay_dict'):
                params['shift_id'] = self.shift_id.to_alipay_dict()
            else:
                params['shift_id'] = self.shift_id
        if self.trip_chain:
            if hasattr(self.trip_chain, 'to_alipay_dict'):
                params['trip_chain'] = self.trip_chain.to_alipay_dict()
            else:
                params['trip_chain'] = self.trip_chain
        if self.valid_miles:
            if hasattr(self.valid_miles, 'to_alipay_dict'):
                params['valid_miles'] = self.valid_miles.to_alipay_dict()
            else:
                params['valid_miles'] = self.valid_miles
        if self.valid_trip_cnt:
            if hasattr(self.valid_trip_cnt, 'to_alipay_dict'):
                params['valid_trip_cnt'] = self.valid_trip_cnt.to_alipay_dict()
            else:
                params['valid_trip_cnt'] = self.valid_trip_cnt
        if self.wait_time:
            if hasattr(self.wait_time, 'to_alipay_dict'):
                params['wait_time'] = self.wait_time.to_alipay_dict()
            else:
                params['wait_time'] = self.wait_time
        if self.work_endtime:
            if hasattr(self.work_endtime, 'to_alipay_dict'):
                params['work_endtime'] = self.work_endtime.to_alipay_dict()
            else:
                params['work_endtime'] = self.work_endtime
        if self.work_id:
            if hasattr(self.work_id, 'to_alipay_dict'):
                params['work_id'] = self.work_id.to_alipay_dict()
            else:
                params['work_id'] = self.work_id
        if self.work_starttime:
            if hasattr(self.work_starttime, 'to_alipay_dict'):
                params['work_starttime'] = self.work_starttime.to_alipay_dict()
            else:
                params['work_starttime'] = self.work_starttime
        if self.work_time:
            if hasattr(self.work_time, 'to_alipay_dict'):
                params['work_time'] = self.work_time.to_alipay_dict()
            else:
                params['work_time'] = self.work_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScheduleWorkItem()
        if 'all_miles' in d:
            o.all_miles = d['all_miles']
        if 'all_trip_cnt' in d:
            o.all_trip_cnt = d['all_trip_cnt']
        if 'chain_num' in d:
            o.chain_num = d['chain_num']
        if 'invalid_miles' in d:
            o.invalid_miles = d['invalid_miles']
        if 'invalid_trip_cnt' in d:
            o.invalid_trip_cnt = d['invalid_trip_cnt']
        if 'line_id' in d:
            o.line_id = d['line_id']
        if 'opt_type' in d:
            o.opt_type = d['opt_type']
        if 'shift_id' in d:
            o.shift_id = d['shift_id']
        if 'trip_chain' in d:
            o.trip_chain = d['trip_chain']
        if 'valid_miles' in d:
            o.valid_miles = d['valid_miles']
        if 'valid_trip_cnt' in d:
            o.valid_trip_cnt = d['valid_trip_cnt']
        if 'wait_time' in d:
            o.wait_time = d['wait_time']
        if 'work_endtime' in d:
            o.work_endtime = d['work_endtime']
        if 'work_id' in d:
            o.work_id = d['work_id']
        if 'work_starttime' in d:
            o.work_starttime = d['work_starttime']
        if 'work_time' in d:
            o.work_time = d['work_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantStoreShopcodeCreateModel(object):

    def __init__(self):
        self._address = None
        self._category_id = None
        self._city_code = None
        self._district_code = None
        self._latitude = None
        self._longitude = None
        self._merchant_logon_id = None
        self._operator_id = None
        self._out_biz_no = None
        self._phone_no = None
        self._province_code = None
        self._shop_front_photo = None
        self._shop_id = None
        self._shop_name = None
        self._shop_no = None
        self._smid = None
        self._tokens = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def merchant_logon_id(self):
        return self._merchant_logon_id

    @merchant_logon_id.setter
    def merchant_logon_id(self, value):
        self._merchant_logon_id = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def phone_no(self):
        return self._phone_no

    @phone_no.setter
    def phone_no(self, value):
        self._phone_no = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def shop_front_photo(self):
        return self._shop_front_photo

    @shop_front_photo.setter
    def shop_front_photo(self, value):
        self._shop_front_photo = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_no(self):
        return self._shop_no

    @shop_no.setter
    def shop_no(self, value):
        self._shop_no = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def tokens(self):
        return self._tokens

    @tokens.setter
    def tokens(self, value):
        if isinstance(value, list):
            self._tokens = list()
            for i in value:
                self._tokens.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.merchant_logon_id:
            if hasattr(self.merchant_logon_id, 'to_alipay_dict'):
                params['merchant_logon_id'] = self.merchant_logon_id.to_alipay_dict()
            else:
                params['merchant_logon_id'] = self.merchant_logon_id
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.phone_no:
            if hasattr(self.phone_no, 'to_alipay_dict'):
                params['phone_no'] = self.phone_no.to_alipay_dict()
            else:
                params['phone_no'] = self.phone_no
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.shop_front_photo:
            if hasattr(self.shop_front_photo, 'to_alipay_dict'):
                params['shop_front_photo'] = self.shop_front_photo.to_alipay_dict()
            else:
                params['shop_front_photo'] = self.shop_front_photo
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_no:
            if hasattr(self.shop_no, 'to_alipay_dict'):
                params['shop_no'] = self.shop_no.to_alipay_dict()
            else:
                params['shop_no'] = self.shop_no
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.tokens:
            if isinstance(self.tokens, list):
                for i in range(0, len(self.tokens)):
                    element = self.tokens[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tokens[i] = element.to_alipay_dict()
            if hasattr(self.tokens, 'to_alipay_dict'):
                params['tokens'] = self.tokens.to_alipay_dict()
            else:
                params['tokens'] = self.tokens
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantStoreShopcodeCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'merchant_logon_id' in d:
            o.merchant_logon_id = d['merchant_logon_id']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'phone_no' in d:
            o.phone_no = d['phone_no']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'shop_front_photo' in d:
            o.shop_front_photo = d['shop_front_photo']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_no' in d:
            o.shop_no = d['shop_no']
        if 'smid' in d:
            o.smid = d['smid']
        if 'tokens' in d:
            o.tokens = d['tokens']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppGrayCityDto import MiniAppGrayCityDto


class AlipayOpenMiniInnerversionCitygrayQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerversionCitygrayQueryResponse, self).__init__()
        self._city_code = None
        self._city_codes = None
        self._city_name = None
        self._gray_citys = None
        self._rule_code = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_codes(self):
        return self._city_codes

    @city_codes.setter
    def city_codes(self, value):
        if isinstance(value, list):
            self._city_codes = list()
            for i in value:
                self._city_codes.append(i)
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def gray_citys(self):
        return self._gray_citys

    @gray_citys.setter
    def gray_citys(self, value):
        if isinstance(value, list):
            self._gray_citys = list()
            for i in value:
                if isinstance(i, MiniAppGrayCityDto):
                    self._gray_citys.append(i)
                else:
                    self._gray_citys.append(MiniAppGrayCityDto.from_alipay_dict(i))
    @property
    def rule_code(self):
        return self._rule_code

    @rule_code.setter
    def rule_code(self, value):
        self._rule_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerversionCitygrayQueryResponse, self).parse_response_content(response_content)
        if 'city_code' in response:
            self.city_code = response['city_code']
        if 'city_codes' in response:
            self.city_codes = response['city_codes']
        if 'city_name' in response:
            self.city_name = response['city_name']
        if 'gray_citys' in response:
            self.gray_citys = response['gray_citys']
        if 'rule_code' in response:
            self.rule_code = response['rule_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RiskDoc import RiskDoc


class ZhimaCreditEpRiskDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpRiskDetailQueryResponse, self).__init__()
        self._risk_list = None
        self._total_size = None

    @property
    def risk_list(self):
        return self._risk_list

    @risk_list.setter
    def risk_list(self, value):
        if isinstance(value, RiskDoc):
            self._risk_list = value
        else:
            self._risk_list = RiskDoc.from_alipay_dict(value)
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpRiskDetailQueryResponse, self).parse_response_content(response_content)
        if 'risk_list' in response:
            self.risk_list = response['risk_list']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringItemlistQueryModel(object):

    def __init__(self):
        self._auth_code = None
        self._item_status = None
        self._operator_type = None
        self._page_no = None
        self._page_size = None
        self._request_id = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def item_status(self):
        return self._item_status

    @item_status.setter
    def item_status(self, value):
        self._item_status = value
    @property
    def operator_type(self):
        return self._operator_type

    @operator_type.setter
    def operator_type(self, value):
        self._operator_type = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.item_status:
            if hasattr(self.item_status, 'to_alipay_dict'):
                params['item_status'] = self.item_status.to_alipay_dict()
            else:
                params['item_status'] = self.item_status
        if self.operator_type:
            if hasattr(self.operator_type, 'to_alipay_dict'):
                params['operator_type'] = self.operator_type.to_alipay_dict()
            else:
                params['operator_type'] = self.operator_type
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringItemlistQueryModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'item_status' in d:
            o.item_status = d['item_status']
        if 'operator_type' in d:
            o.operator_type = d['operator_type']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataPrinterTokenGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataPrinterTokenGetResponse, self).__init__()
        self._code = None
        self._data = None
        self._message = None
        self._status = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataPrinterTokenGetResponse, self).parse_response_content(response_content)
        if 'code' in response:
            self.code = response['code']
        if 'data' in response:
            self.data = response['data']
        if 'message' in response:
            self.message = response['message']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransAacollectBatchCloseModel(object):

    def __init__(self):
        self._batch_no = None
        self._batch_token = None
        self._current_user_id = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def batch_token(self):
        return self._batch_token

    @batch_token.setter
    def batch_token(self, value):
        self._batch_token = value
    @property
    def current_user_id(self):
        return self._current_user_id

    @current_user_id.setter
    def current_user_id(self, value):
        self._current_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.batch_token:
            if hasattr(self.batch_token, 'to_alipay_dict'):
                params['batch_token'] = self.batch_token.to_alipay_dict()
            else:
                params['batch_token'] = self.batch_token
        if self.current_user_id:
            if hasattr(self.current_user_id, 'to_alipay_dict'):
                params['current_user_id'] = self.current_user_id.to_alipay_dict()
            else:
                params['current_user_id'] = self.current_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransAacollectBatchCloseModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'batch_token' in d:
            o.batch_token = d['batch_token']
        if 'current_user_id' in d:
            o.current_user_id = d['current_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ZMGOBasicConfig import ZMGOBasicConfig
from alipay.aop.api.domain.ZMGOExtConfig import ZMGOExtConfig
from alipay.aop.api.domain.ZMGOObligationConfig import ZMGOObligationConfig
from alipay.aop.api.domain.ZMGOOpenConfig import ZMGOOpenConfig
from alipay.aop.api.domain.ZMGOQuitConfig import ZMGOQuitConfig
from alipay.aop.api.domain.ZMGORightConfig import ZMGORightConfig
from alipay.aop.api.domain.ZMGOSettlementConfig import ZMGOSettlementConfig


class ZhimaMerchantZmgoTemplateCreateModel(object):

    def __init__(self):
        self._basic_config = None
        self._ext_config = None
        self._obligation_config = None
        self._open_config = None
        self._quit_config = None
        self._right_config = None
        self._settlement_config = None

    @property
    def basic_config(self):
        return self._basic_config

    @basic_config.setter
    def basic_config(self, value):
        if isinstance(value, ZMGOBasicConfig):
            self._basic_config = value
        else:
            self._basic_config = ZMGOBasicConfig.from_alipay_dict(value)
    @property
    def ext_config(self):
        return self._ext_config

    @ext_config.setter
    def ext_config(self, value):
        if isinstance(value, ZMGOExtConfig):
            self._ext_config = value
        else:
            self._ext_config = ZMGOExtConfig.from_alipay_dict(value)
    @property
    def obligation_config(self):
        return self._obligation_config

    @obligation_config.setter
    def obligation_config(self, value):
        if isinstance(value, ZMGOObligationConfig):
            self._obligation_config = value
        else:
            self._obligation_config = ZMGOObligationConfig.from_alipay_dict(value)
    @property
    def open_config(self):
        return self._open_config

    @open_config.setter
    def open_config(self, value):
        if isinstance(value, ZMGOOpenConfig):
            self._open_config = value
        else:
            self._open_config = ZMGOOpenConfig.from_alipay_dict(value)
    @property
    def quit_config(self):
        return self._quit_config

    @quit_config.setter
    def quit_config(self, value):
        if isinstance(value, ZMGOQuitConfig):
            self._quit_config = value
        else:
            self._quit_config = ZMGOQuitConfig.from_alipay_dict(value)
    @property
    def right_config(self):
        return self._right_config

    @right_config.setter
    def right_config(self, value):
        if isinstance(value, ZMGORightConfig):
            self._right_config = value
        else:
            self._right_config = ZMGORightConfig.from_alipay_dict(value)
    @property
    def settlement_config(self):
        return self._settlement_config

    @settlement_config.setter
    def settlement_config(self, value):
        if isinstance(value, ZMGOSettlementConfig):
            self._settlement_config = value
        else:
            self._settlement_config = ZMGOSettlementConfig.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.basic_config:
            if hasattr(self.basic_config, 'to_alipay_dict'):
                params['basic_config'] = self.basic_config.to_alipay_dict()
            else:
                params['basic_config'] = self.basic_config
        if self.ext_config:
            if hasattr(self.ext_config, 'to_alipay_dict'):
                params['ext_config'] = self.ext_config.to_alipay_dict()
            else:
                params['ext_config'] = self.ext_config
        if self.obligation_config:
            if hasattr(self.obligation_config, 'to_alipay_dict'):
                params['obligation_config'] = self.obligation_config.to_alipay_dict()
            else:
                params['obligation_config'] = self.obligation_config
        if self.open_config:
            if hasattr(self.open_config, 'to_alipay_dict'):
                params['open_config'] = self.open_config.to_alipay_dict()
            else:
                params['open_config'] = self.open_config
        if self.quit_config:
            if hasattr(self.quit_config, 'to_alipay_dict'):
                params['quit_config'] = self.quit_config.to_alipay_dict()
            else:
                params['quit_config'] = self.quit_config
        if self.right_config:
            if hasattr(self.right_config, 'to_alipay_dict'):
                params['right_config'] = self.right_config.to_alipay_dict()
            else:
                params['right_config'] = self.right_config
        if self.settlement_config:
            if hasattr(self.settlement_config, 'to_alipay_dict'):
                params['settlement_config'] = self.settlement_config.to_alipay_dict()
            else:
                params['settlement_config'] = self.settlement_config
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantZmgoTemplateCreateModel()
        if 'basic_config' in d:
            o.basic_config = d['basic_config']
        if 'ext_config' in d:
            o.ext_config = d['ext_config']
        if 'obligation_config' in d:
            o.obligation_config = d['obligation_config']
        if 'open_config' in d:
            o.open_config = d['open_config']
        if 'quit_config' in d:
            o.quit_config = d['quit_config']
        if 'right_config' in d:
            o.right_config = d['right_config']
        if 'settlement_config' in d:
            o.settlement_config = d['settlement_config']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechMorseMarketingRtaSendModel(object):

    def __init__(self):
        self._campaign_id = None
        self._cert_encryption = None
        self._encryption_type = None
        self._extend_params = None
        self._login_id_encryption = None
        self._mobile_encryption = None
        self._out_biz_no = None
        self._resource_id = None
        self._send_type = None

    @property
    def campaign_id(self):
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, value):
        self._campaign_id = value
    @property
    def cert_encryption(self):
        return self._cert_encryption

    @cert_encryption.setter
    def cert_encryption(self, value):
        self._cert_encryption = value
    @property
    def encryption_type(self):
        return self._encryption_type

    @encryption_type.setter
    def encryption_type(self, value):
        self._encryption_type = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def login_id_encryption(self):
        return self._login_id_encryption

    @login_id_encryption.setter
    def login_id_encryption(self, value):
        self._login_id_encryption = value
    @property
    def mobile_encryption(self):
        return self._mobile_encryption

    @mobile_encryption.setter
    def mobile_encryption(self, value):
        self._mobile_encryption = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, value):
        self._resource_id = value
    @property
    def send_type(self):
        return self._send_type

    @send_type.setter
    def send_type(self, value):
        self._send_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.campaign_id:
            if hasattr(self.campaign_id, 'to_alipay_dict'):
                params['campaign_id'] = self.campaign_id.to_alipay_dict()
            else:
                params['campaign_id'] = self.campaign_id
        if self.cert_encryption:
            if hasattr(self.cert_encryption, 'to_alipay_dict'):
                params['cert_encryption'] = self.cert_encryption.to_alipay_dict()
            else:
                params['cert_encryption'] = self.cert_encryption
        if self.encryption_type:
            if hasattr(self.encryption_type, 'to_alipay_dict'):
                params['encryption_type'] = self.encryption_type.to_alipay_dict()
            else:
                params['encryption_type'] = self.encryption_type
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.login_id_encryption:
            if hasattr(self.login_id_encryption, 'to_alipay_dict'):
                params['login_id_encryption'] = self.login_id_encryption.to_alipay_dict()
            else:
                params['login_id_encryption'] = self.login_id_encryption
        if self.mobile_encryption:
            if hasattr(self.mobile_encryption, 'to_alipay_dict'):
                params['mobile_encryption'] = self.mobile_encryption.to_alipay_dict()
            else:
                params['mobile_encryption'] = self.mobile_encryption
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.resource_id:
            if hasattr(self.resource_id, 'to_alipay_dict'):
                params['resource_id'] = self.resource_id.to_alipay_dict()
            else:
                params['resource_id'] = self.resource_id
        if self.send_type:
            if hasattr(self.send_type, 'to_alipay_dict'):
                params['send_type'] = self.send_type.to_alipay_dict()
            else:
                params['send_type'] = self.send_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechMorseMarketingRtaSendModel()
        if 'campaign_id' in d:
            o.campaign_id = d['campaign_id']
        if 'cert_encryption' in d:
            o.cert_encryption = d['cert_encryption']
        if 'encryption_type' in d:
            o.encryption_type = d['encryption_type']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'login_id_encryption' in d:
            o.login_id_encryption = d['login_id_encryption']
        if 'mobile_encryption' in d:
            o.mobile_encryption = d['mobile_encryption']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'resource_id' in d:
            o.resource_id = d['resource_id']
        if 'send_type' in d:
            o.send_type = d['send_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreditPayUserVO import CreditPayUserVO


class MybankCreditLoantradePayeeArConsultModel(object):

    def __init__(self):
        self._biz_scene = None
        self._sub_biz_scene = None
        self._user_info = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def sub_biz_scene(self):
        return self._sub_biz_scene

    @sub_biz_scene.setter
    def sub_biz_scene(self, value):
        self._sub_biz_scene = value
    @property
    def user_info(self):
        return self._user_info

    @user_info.setter
    def user_info(self, value):
        if isinstance(value, CreditPayUserVO):
            self._user_info = value
        else:
            self._user_info = CreditPayUserVO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.sub_biz_scene:
            if hasattr(self.sub_biz_scene, 'to_alipay_dict'):
                params['sub_biz_scene'] = self.sub_biz_scene.to_alipay_dict()
            else:
                params['sub_biz_scene'] = self.sub_biz_scene
        if self.user_info:
            if hasattr(self.user_info, 'to_alipay_dict'):
                params['user_info'] = self.user_info.to_alipay_dict()
            else:
                params['user_info'] = self.user_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradePayeeArConsultModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'sub_biz_scene' in d:
            o.sub_biz_scene = d['sub_biz_scene']
        if 'user_info' in d:
            o.user_info = d['user_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundCouponWufuCardAcceptResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponWufuCardAcceptResponse, self).__init__()
        self._card_name = None
        self._card_type = None

    @property
    def card_name(self):
        return self._card_name

    @card_name.setter
    def card_name(self, value):
        self._card_name = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponWufuCardAcceptResponse, self).parse_response_content(response_content)
        if 'card_name' in response:
            self.card_name = response['card_name']
        if 'card_type' in response:
            self.card_type = response['card_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdFingerprintApplyInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdFingerprintApplyInitializeResponse, self).__init__()
        self._server_response = None

    @property
    def server_response(self):
        return self._server_response

    @server_response.setter
    def server_response(self, value):
        self._server_response = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdFingerprintApplyInitializeResponse, self).parse_response_content(response_content)
        if 'server_response' in response:
            self.server_response = response['server_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEcApprovalModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEcApprovalModifyResponse, self).__init__()
        self._platform_approval_id = None

    @property
    def platform_approval_id(self):
        return self._platform_approval_id

    @platform_approval_id.setter
    def platform_approval_id(self, value):
        self._platform_approval_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEcApprovalModifyResponse, self).parse_response_content(response_content)
        if 'platform_approval_id' in response:
            self.platform_approval_id = response['platform_approval_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class WaybillInvoice(object):

    def __init__(self):
        self._waybill_amount = None
        self._waybill_no = None

    @property
    def waybill_amount(self):
        return self._waybill_amount

    @waybill_amount.setter
    def waybill_amount(self, value):
        self._waybill_amount = value
    @property
    def waybill_no(self):
        return self._waybill_no

    @waybill_no.setter
    def waybill_no(self, value):
        self._waybill_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.waybill_amount:
            if hasattr(self.waybill_amount, 'to_alipay_dict'):
                params['waybill_amount'] = self.waybill_amount.to_alipay_dict()
            else:
                params['waybill_amount'] = self.waybill_amount
        if self.waybill_no:
            if hasattr(self.waybill_no, 'to_alipay_dict'):
                params['waybill_no'] = self.waybill_no.to_alipay_dict()
            else:
                params['waybill_no'] = self.waybill_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WaybillInvoice()
        if 'waybill_amount' in d:
            o.waybill_amount = d['waybill_amount']
        if 'waybill_no' in d:
            o.waybill_no = d['waybill_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppYiyiyiwuQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppYiyiyiwuQueryResponse, self).__init__()
        self._chucan = None

    @property
    def chucan(self):
        return self._chucan

    @chucan.setter
    def chucan(self, value):
        self._chucan = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppYiyiyiwuQueryResponse, self).parse_response_content(response_content)
        if 'chucan' in response:
            self.chucan = response['chucan']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotDeviceEcobindQueryModel(object):

    def __init__(self):
        self._bind_type = None
        self._biz_tid = None
        self._identify_type = None
        self._sn = None
        self._supplier_id = None

    @property
    def bind_type(self):
        return self._bind_type

    @bind_type.setter
    def bind_type(self, value):
        self._bind_type = value
    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def identify_type(self):
        return self._identify_type

    @identify_type.setter
    def identify_type(self, value):
        self._identify_type = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bind_type:
            if hasattr(self.bind_type, 'to_alipay_dict'):
                params['bind_type'] = self.bind_type.to_alipay_dict()
            else:
                params['bind_type'] = self.bind_type
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.identify_type:
            if hasattr(self.identify_type, 'to_alipay_dict'):
                params['identify_type'] = self.identify_type.to_alipay_dict()
            else:
                params['identify_type'] = self.identify_type
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotDeviceEcobindQueryModel()
        if 'bind_type' in d:
            o.bind_type = d['bind_type']
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'identify_type' in d:
            o.identify_type = d['identify_type']
        if 'sn' in d:
            o.sn = d['sn']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAntpaasTokenidentityQueryModel(object):

    def __init__(self):
        self._biz_id = None
        self._biz_scene = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAntpaasTokenidentityQueryModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivityGoodsBenefit import ActivityGoodsBenefit


class ActivityOperateContext(object):

    def __init__(self):
        self._activity_goods_benefit = None
        self._activity_status = None

    @property
    def activity_goods_benefit(self):
        return self._activity_goods_benefit

    @activity_goods_benefit.setter
    def activity_goods_benefit(self, value):
        if isinstance(value, ActivityGoodsBenefit):
            self._activity_goods_benefit = value
        else:
            self._activity_goods_benefit = ActivityGoodsBenefit.from_alipay_dict(value)
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_goods_benefit:
            if hasattr(self.activity_goods_benefit, 'to_alipay_dict'):
                params['activity_goods_benefit'] = self.activity_goods_benefit.to_alipay_dict()
            else:
                params['activity_goods_benefit'] = self.activity_goods_benefit
        if self.activity_status:
            if hasattr(self.activity_status, 'to_alipay_dict'):
                params['activity_status'] = self.activity_status.to_alipay_dict()
            else:
                params['activity_status'] = self.activity_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityOperateContext()
        if 'activity_goods_benefit' in d:
            o.activity_goods_benefit = d['activity_goods_benefit']
        if 'activity_status' in d:
            o.activity_status = d['activity_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAgreementSignConfirmModel(object):

    def __init__(self):
        self._apply_token = None
        self._cert_no = None
        self._confirm_no = None

    @property
    def apply_token(self):
        return self._apply_token

    @apply_token.setter
    def apply_token(self, value):
        self._apply_token = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def confirm_no(self):
        return self._confirm_no

    @confirm_no.setter
    def confirm_no(self, value):
        self._confirm_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_token:
            if hasattr(self.apply_token, 'to_alipay_dict'):
                params['apply_token'] = self.apply_token.to_alipay_dict()
            else:
                params['apply_token'] = self.apply_token
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.confirm_no:
            if hasattr(self.confirm_no, 'to_alipay_dict'):
                params['confirm_no'] = self.confirm_no.to_alipay_dict()
            else:
                params['confirm_no'] = self.confirm_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementSignConfirmModel()
        if 'apply_token' in d:
            o.apply_token = d['apply_token']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'confirm_no' in d:
            o.confirm_no = d['confirm_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishDictionary(object):

    def __init__(self):
        self._create_user = None
        self._dictionary_id = None
        self._ext_info = None
        self._merchant_id = None
        self._name = None
        self._status = None
        self._update_user = None

    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def dictionary_id(self):
        return self._dictionary_id

    @dictionary_id.setter
    def dictionary_id(self, value):
        self._dictionary_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.dictionary_id:
            if hasattr(self.dictionary_id, 'to_alipay_dict'):
                params['dictionary_id'] = self.dictionary_id.to_alipay_dict()
            else:
                params['dictionary_id'] = self.dictionary_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishDictionary()
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'dictionary_id' in d:
            o.dictionary_id = d['dictionary_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'name' in d:
            o.name = d['name']
        if 'status' in d:
            o.status = d['status']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VehicleDashboardResult(object):

    def __init__(self):
        self._class_name = None
        self._label = None
        self._score = None

    @property
    def class_name(self):
        return self._class_name

    @class_name.setter
    def class_name(self, value):
        self._class_name = value
    @property
    def label(self):
        return self._label

    @label.setter
    def label(self, value):
        self._label = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value


    def to_alipay_dict(self):
        params = dict()
        if self.class_name:
            if hasattr(self.class_name, 'to_alipay_dict'):
                params['class_name'] = self.class_name.to_alipay_dict()
            else:
                params['class_name'] = self.class_name
        if self.label:
            if hasattr(self.label, 'to_alipay_dict'):
                params['label'] = self.label.to_alipay_dict()
            else:
                params['label'] = self.label
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VehicleDashboardResult()
        if 'class_name' in d:
            o.class_name = d['class_name']
        if 'label' in d:
            o.label = d['label']
        if 'score' in d:
            o.score = d['score']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerEpIdentificationQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerEpIdentificationQueryResponse, self).__init__()
        self._ep_cert_no = None
        self._ep_name = None
        self._failed_code = None
        self._passed = None

    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def failed_code(self):
        return self._failed_code

    @failed_code.setter
    def failed_code(self, value):
        self._failed_code = value
    @property
    def passed(self):
        return self._passed

    @passed.setter
    def passed(self, value):
        self._passed = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerEpIdentificationQueryResponse, self).parse_response_content(response_content)
        if 'ep_cert_no' in response:
            self.ep_cert_no = response['ep_cert_no']
        if 'ep_name' in response:
            self.ep_name = response['ep_name']
        if 'failed_code' in response:
            self.failed_code = response['failed_code']
        if 'passed' in response:
            self.passed = response['passed']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KmsBakingInventoryDTO(object):

    def __init__(self):
        self._accumulate_inventory = None
        self._data_id = None
        self._ending_inventory = None
        self._ending_position = None
        self._opening_inventory = None
        self._operation_name = None
        self._operation_num = None
        self._operation_time = None
        self._operator = None
        self._sku_batch = None
        self._sku_id = None
        self._starting_position = None

    @property
    def accumulate_inventory(self):
        return self._accumulate_inventory

    @accumulate_inventory.setter
    def accumulate_inventory(self, value):
        self._accumulate_inventory = value
    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def ending_inventory(self):
        return self._ending_inventory

    @ending_inventory.setter
    def ending_inventory(self, value):
        self._ending_inventory = value
    @property
    def ending_position(self):
        return self._ending_position

    @ending_position.setter
    def ending_position(self, value):
        self._ending_position = value
    @property
    def opening_inventory(self):
        return self._opening_inventory

    @opening_inventory.setter
    def opening_inventory(self, value):
        self._opening_inventory = value
    @property
    def operation_name(self):
        return self._operation_name

    @operation_name.setter
    def operation_name(self, value):
        self._operation_name = value
    @property
    def operation_num(self):
        return self._operation_num

    @operation_num.setter
    def operation_num(self, value):
        self._operation_num = value
    @property
    def operation_time(self):
        return self._operation_time

    @operation_time.setter
    def operation_time(self, value):
        self._operation_time = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def sku_batch(self):
        return self._sku_batch

    @sku_batch.setter
    def sku_batch(self, value):
        self._sku_batch = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def starting_position(self):
        return self._starting_position

    @starting_position.setter
    def starting_position(self, value):
        self._starting_position = value


    def to_alipay_dict(self):
        params = dict()
        if self.accumulate_inventory:
            if hasattr(self.accumulate_inventory, 'to_alipay_dict'):
                params['accumulate_inventory'] = self.accumulate_inventory.to_alipay_dict()
            else:
                params['accumulate_inventory'] = self.accumulate_inventory
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.ending_inventory:
            if hasattr(self.ending_inventory, 'to_alipay_dict'):
                params['ending_inventory'] = self.ending_inventory.to_alipay_dict()
            else:
                params['ending_inventory'] = self.ending_inventory
        if self.ending_position:
            if hasattr(self.ending_position, 'to_alipay_dict'):
                params['ending_position'] = self.ending_position.to_alipay_dict()
            else:
                params['ending_position'] = self.ending_position
        if self.opening_inventory:
            if hasattr(self.opening_inventory, 'to_alipay_dict'):
                params['opening_inventory'] = self.opening_inventory.to_alipay_dict()
            else:
                params['opening_inventory'] = self.opening_inventory
        if self.operation_name:
            if hasattr(self.operation_name, 'to_alipay_dict'):
                params['operation_name'] = self.operation_name.to_alipay_dict()
            else:
                params['operation_name'] = self.operation_name
        if self.operation_num:
            if hasattr(self.operation_num, 'to_alipay_dict'):
                params['operation_num'] = self.operation_num.to_alipay_dict()
            else:
                params['operation_num'] = self.operation_num
        if self.operation_time:
            if hasattr(self.operation_time, 'to_alipay_dict'):
                params['operation_time'] = self.operation_time.to_alipay_dict()
            else:
                params['operation_time'] = self.operation_time
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.sku_batch:
            if hasattr(self.sku_batch, 'to_alipay_dict'):
                params['sku_batch'] = self.sku_batch.to_alipay_dict()
            else:
                params['sku_batch'] = self.sku_batch
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.starting_position:
            if hasattr(self.starting_position, 'to_alipay_dict'):
                params['starting_position'] = self.starting_position.to_alipay_dict()
            else:
                params['starting_position'] = self.starting_position
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KmsBakingInventoryDTO()
        if 'accumulate_inventory' in d:
            o.accumulate_inventory = d['accumulate_inventory']
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'ending_inventory' in d:
            o.ending_inventory = d['ending_inventory']
        if 'ending_position' in d:
            o.ending_position = d['ending_position']
        if 'opening_inventory' in d:
            o.opening_inventory = d['opening_inventory']
        if 'operation_name' in d:
            o.operation_name = d['operation_name']
        if 'operation_num' in d:
            o.operation_num = d['operation_num']
        if 'operation_time' in d:
            o.operation_time = d['operation_time']
        if 'operator' in d:
            o.operator = d['operator']
        if 'sku_batch' in d:
            o.sku_batch = d['sku_batch']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'starting_position' in d:
            o.starting_position = d['starting_position']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PeriodInfo import PeriodInfo


class ValidDateInfo(object):

    def __init__(self):
        self._end_time = None
        self._relative_time = None
        self._start_time = None
        self._time_mode = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def relative_time(self):
        return self._relative_time

    @relative_time.setter
    def relative_time(self, value):
        if isinstance(value, PeriodInfo):
            self._relative_time = value
        else:
            self._relative_time = PeriodInfo.from_alipay_dict(value)
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def time_mode(self):
        return self._time_mode

    @time_mode.setter
    def time_mode(self, value):
        self._time_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.relative_time:
            if hasattr(self.relative_time, 'to_alipay_dict'):
                params['relative_time'] = self.relative_time.to_alipay_dict()
            else:
                params['relative_time'] = self.relative_time
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.time_mode:
            if hasattr(self.time_mode, 'to_alipay_dict'):
                params['time_mode'] = self.time_mode.to_alipay_dict()
            else:
                params['time_mode'] = self.time_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ValidDateInfo()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'relative_time' in d:
            o.relative_time = d['relative_time']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'time_mode' in d:
            o.time_mode = d['time_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingDeviceorderSyncModel(object):

    def __init__(self):
        self._alipay_parking_id = None
        self._alipay_supplier_sn = None
        self._applicant_alipay_account = None
        self._applicant_name = None
        self._applicant_phone = None
        self._biz_time = None
        self._booth_num = None
        self._device_num = None
        self._device_type = None
        self._order_id = None
        self._order_state = None
        self._pklot_principal_name = None
        self._pklot_principal_phone = None
        self._receiver_address = None
        self._receiver_name = None
        self._receiver_phone = None
        self._remarks = None

    @property
    def alipay_parking_id(self):
        return self._alipay_parking_id

    @alipay_parking_id.setter
    def alipay_parking_id(self, value):
        self._alipay_parking_id = value
    @property
    def alipay_supplier_sn(self):
        return self._alipay_supplier_sn

    @alipay_supplier_sn.setter
    def alipay_supplier_sn(self, value):
        self._alipay_supplier_sn = value
    @property
    def applicant_alipay_account(self):
        return self._applicant_alipay_account

    @applicant_alipay_account.setter
    def applicant_alipay_account(self, value):
        self._applicant_alipay_account = value
    @property
    def applicant_name(self):
        return self._applicant_name

    @applicant_name.setter
    def applicant_name(self, value):
        self._applicant_name = value
    @property
    def applicant_phone(self):
        return self._applicant_phone

    @applicant_phone.setter
    def applicant_phone(self, value):
        self._applicant_phone = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def booth_num(self):
        return self._booth_num

    @booth_num.setter
    def booth_num(self, value):
        self._booth_num = value
    @property
    def device_num(self):
        return self._device_num

    @device_num.setter
    def device_num(self, value):
        self._device_num = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_state(self):
        return self._order_state

    @order_state.setter
    def order_state(self, value):
        self._order_state = value
    @property
    def pklot_principal_name(self):
        return self._pklot_principal_name

    @pklot_principal_name.setter
    def pklot_principal_name(self, value):
        self._pklot_principal_name = value
    @property
    def pklot_principal_phone(self):
        return self._pklot_principal_phone

    @pklot_principal_phone.setter
    def pklot_principal_phone(self, value):
        self._pklot_principal_phone = value
    @property
    def receiver_address(self):
        return self._receiver_address

    @receiver_address.setter
    def receiver_address(self, value):
        self._receiver_address = value
    @property
    def receiver_name(self):
        return self._receiver_name

    @receiver_name.setter
    def receiver_name(self, value):
        self._receiver_name = value
    @property
    def receiver_phone(self):
        return self._receiver_phone

    @receiver_phone.setter
    def receiver_phone(self, value):
        self._receiver_phone = value
    @property
    def remarks(self):
        return self._remarks

    @remarks.setter
    def remarks(self, value):
        self._remarks = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_parking_id:
            if hasattr(self.alipay_parking_id, 'to_alipay_dict'):
                params['alipay_parking_id'] = self.alipay_parking_id.to_alipay_dict()
            else:
                params['alipay_parking_id'] = self.alipay_parking_id
        if self.alipay_supplier_sn:
            if hasattr(self.alipay_supplier_sn, 'to_alipay_dict'):
                params['alipay_supplier_sn'] = self.alipay_supplier_sn.to_alipay_dict()
            else:
                params['alipay_supplier_sn'] = self.alipay_supplier_sn
        if self.applicant_alipay_account:
            if hasattr(self.applicant_alipay_account, 'to_alipay_dict'):
                params['applicant_alipay_account'] = self.applicant_alipay_account.to_alipay_dict()
            else:
                params['applicant_alipay_account'] = self.applicant_alipay_account
        if self.applicant_name:
            if hasattr(self.applicant_name, 'to_alipay_dict'):
                params['applicant_name'] = self.applicant_name.to_alipay_dict()
            else:
                params['applicant_name'] = self.applicant_name
        if self.applicant_phone:
            if hasattr(self.applicant_phone, 'to_alipay_dict'):
                params['applicant_phone'] = self.applicant_phone.to_alipay_dict()
            else:
                params['applicant_phone'] = self.applicant_phone
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.booth_num:
            if hasattr(self.booth_num, 'to_alipay_dict'):
                params['booth_num'] = self.booth_num.to_alipay_dict()
            else:
                params['booth_num'] = self.booth_num
        if self.device_num:
            if hasattr(self.device_num, 'to_alipay_dict'):
                params['device_num'] = self.device_num.to_alipay_dict()
            else:
                params['device_num'] = self.device_num
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_state:
            if hasattr(self.order_state, 'to_alipay_dict'):
                params['order_state'] = self.order_state.to_alipay_dict()
            else:
                params['order_state'] = self.order_state
        if self.pklot_principal_name:
            if hasattr(self.pklot_principal_name, 'to_alipay_dict'):
                params['pklot_principal_name'] = self.pklot_principal_name.to_alipay_dict()
            else:
                params['pklot_principal_name'] = self.pklot_principal_name
        if self.pklot_principal_phone:
            if hasattr(self.pklot_principal_phone, 'to_alipay_dict'):
                params['pklot_principal_phone'] = self.pklot_principal_phone.to_alipay_dict()
            else:
                params['pklot_principal_phone'] = self.pklot_principal_phone
        if self.receiver_address:
            if hasattr(self.receiver_address, 'to_alipay_dict'):
                params['receiver_address'] = self.receiver_address.to_alipay_dict()
            else:
                params['receiver_address'] = self.receiver_address
        if self.receiver_name:
            if hasattr(self.receiver_name, 'to_alipay_dict'):
                params['receiver_name'] = self.receiver_name.to_alipay_dict()
            else:
                params['receiver_name'] = self.receiver_name
        if self.receiver_phone:
            if hasattr(self.receiver_phone, 'to_alipay_dict'):
                params['receiver_phone'] = self.receiver_phone.to_alipay_dict()
            else:
                params['receiver_phone'] = self.receiver_phone
        if self.remarks:
            if hasattr(self.remarks, 'to_alipay_dict'):
                params['remarks'] = self.remarks.to_alipay_dict()
            else:
                params['remarks'] = self.remarks
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingDeviceorderSyncModel()
        if 'alipay_parking_id' in d:
            o.alipay_parking_id = d['alipay_parking_id']
        if 'alipay_supplier_sn' in d:
            o.alipay_supplier_sn = d['alipay_supplier_sn']
        if 'applicant_alipay_account' in d:
            o.applicant_alipay_account = d['applicant_alipay_account']
        if 'applicant_name' in d:
            o.applicant_name = d['applicant_name']
        if 'applicant_phone' in d:
            o.applicant_phone = d['applicant_phone']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'booth_num' in d:
            o.booth_num = d['booth_num']
        if 'device_num' in d:
            o.device_num = d['device_num']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_state' in d:
            o.order_state = d['order_state']
        if 'pklot_principal_name' in d:
            o.pklot_principal_name = d['pklot_principal_name']
        if 'pklot_principal_phone' in d:
            o.pklot_principal_phone = d['pklot_principal_phone']
        if 'receiver_address' in d:
            o.receiver_address = d['receiver_address']
        if 'receiver_name' in d:
            o.receiver_name = d['receiver_name']
        if 'receiver_phone' in d:
            o.receiver_phone = d['receiver_phone']
        if 'remarks' in d:
            o.remarks = d['remarks']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsAutoAutoinsprodUserCertifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsAutoAutoinsprodUserCertifyResponse, self).__init__()
        self._agent_cert_result = None

    @property
    def agent_cert_result(self):
        return self._agent_cert_result

    @agent_cert_result.setter
    def agent_cert_result(self, value):
        self._agent_cert_result = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsAutoAutoinsprodUserCertifyResponse, self).parse_response_content(response_content)
        if 'agent_cert_result' in response:
            self.agent_cert_result = response['agent_cert_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateInfoScoreQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateInfoScoreQueryResponse, self).__init__()
        self._score_evaluate = None
        self._score_type = None
        self._score_value = None

    @property
    def score_evaluate(self):
        return self._score_evaluate

    @score_evaluate.setter
    def score_evaluate(self, value):
        self._score_evaluate = value
    @property
    def score_type(self):
        return self._score_type

    @score_type.setter
    def score_type(self, value):
        self._score_type = value
    @property
    def score_value(self):
        return self._score_value

    @score_value.setter
    def score_value(self, value):
        self._score_value = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateInfoScoreQueryResponse, self).parse_response_content(response_content)
        if 'score_evaluate' in response:
            self.score_evaluate = response['score_evaluate']
        if 'score_type' in response:
            self.score_type = response['score_type']
        if 'score_value' in response:
            self.score_value = response['score_value']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BillInfo import BillInfo


class AlipayOpenIotbpaasLavidabilllistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotbpaasLavidabilllistQueryResponse, self).__init__()
        self._bill_count = None
        self._bill_list = None

    @property
    def bill_count(self):
        return self._bill_count

    @bill_count.setter
    def bill_count(self, value):
        self._bill_count = value
    @property
    def bill_list(self):
        return self._bill_list

    @bill_list.setter
    def bill_list(self, value):
        if isinstance(value, list):
            self._bill_list = list()
            for i in value:
                if isinstance(i, BillInfo):
                    self._bill_list.append(i)
                else:
                    self._bill_list.append(BillInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotbpaasLavidabilllistQueryResponse, self).parse_response_content(response_content)
        if 'bill_count' in response:
            self.bill_count = response['bill_count']
        if 'bill_list' in response:
            self.bill_list = response['bill_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CardCreditInfo(object):

    def __init__(self):
        self._allowoverpay = None
        self._creditquota = None

    @property
    def allowoverpay(self):
        return self._allowoverpay

    @allowoverpay.setter
    def allowoverpay(self, value):
        self._allowoverpay = value
    @property
    def creditquota(self):
        return self._creditquota

    @creditquota.setter
    def creditquota(self, value):
        self._creditquota = value


    def to_alipay_dict(self):
        params = dict()
        if self.allowoverpay:
            if hasattr(self.allowoverpay, 'to_alipay_dict'):
                params['allowoverpay'] = self.allowoverpay.to_alipay_dict()
            else:
                params['allowoverpay'] = self.allowoverpay
        if self.creditquota:
            if hasattr(self.creditquota, 'to_alipay_dict'):
                params['creditquota'] = self.creditquota.to_alipay_dict()
            else:
                params['creditquota'] = self.creditquota
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardCreditInfo()
        if 'allowoverpay' in d:
            o.allowoverpay = d['allowoverpay']
        if 'creditquota' in d:
            o.creditquota = d['creditquota']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenIotContentBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotContentBatchqueryResponse, self).__init__()
        self._content_list = None
        self._list_total_count = None
        self._message = None
        self._query_result_code = None
        self._query_token = None

    @property
    def content_list(self):
        return self._content_list

    @content_list.setter
    def content_list(self, value):
        if isinstance(value, list):
            self._content_list = list()
            for i in value:
                self._content_list.append(i)
    @property
    def list_total_count(self):
        return self._list_total_count

    @list_total_count.setter
    def list_total_count(self, value):
        self._list_total_count = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def query_result_code(self):
        return self._query_result_code

    @query_result_code.setter
    def query_result_code(self, value):
        self._query_result_code = value
    @property
    def query_token(self):
        return self._query_token

    @query_token.setter
    def query_token(self, value):
        self._query_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotContentBatchqueryResponse, self).parse_response_content(response_content)
        if 'content_list' in response:
            self.content_list = response['content_list']
        if 'list_total_count' in response:
            self.list_total_count = response['list_total_count']
        if 'message' in response:
            self.message = response['message']
        if 'query_result_code' in response:
            self.query_result_code = response['query_result_code']
        if 'query_token' in response:
            self.query_token = response['query_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppPdeductSignQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppPdeductSignQueryResponse, self).__init__()
        self._agreement_id = None
        self._bill_key = None
        self._charge_inst = None
        self._out_agreement_id = None
        self._sign_date = None
        self._user_id = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def out_agreement_id(self):
        return self._out_agreement_id

    @out_agreement_id.setter
    def out_agreement_id(self, value):
        self._out_agreement_id = value
    @property
    def sign_date(self):
        return self._sign_date

    @sign_date.setter
    def sign_date(self, value):
        self._sign_date = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppPdeductSignQueryResponse, self).parse_response_content(response_content)
        if 'agreement_id' in response:
            self.agreement_id = response['agreement_id']
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'out_agreement_id' in response:
            self.out_agreement_id = response['out_agreement_id']
        if 'sign_date' in response:
            self.sign_date = response['sign_date']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class TechriskInnovateMpcpromoSceneCreateResponse(AlipayResponse):

    def __init__(self):
        super(TechriskInnovateMpcpromoSceneCreateResponse, self).__init__()
        self._illegal_goods_list = None
        self._scene_id = None

    @property
    def illegal_goods_list(self):
        return self._illegal_goods_list

    @illegal_goods_list.setter
    def illegal_goods_list(self, value):
        if isinstance(value, list):
            self._illegal_goods_list = list()
            for i in value:
                self._illegal_goods_list.append(i)
    @property
    def scene_id(self):
        return self._scene_id

    @scene_id.setter
    def scene_id(self, value):
        self._scene_id = value

    def parse_response_content(self, response_content):
        response = super(TechriskInnovateMpcpromoSceneCreateResponse, self).parse_response_content(response_content)
        if 'illegal_goods_list' in response:
            self.illegal_goods_list = response['illegal_goods_list']
        if 'scene_id' in response:
            self.scene_id = response['scene_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseChatGroupsQueryModel(object):

    def __init__(self):
        self._last_key = None

    @property
    def last_key(self):
        return self._last_key

    @last_key.setter
    def last_key(self, value):
        self._last_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.last_key:
            if hasattr(self.last_key, 'to_alipay_dict'):
                params['last_key'] = self.last_key.to_alipay_dict()
            else:
                params['last_key'] = self.last_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseChatGroupsQueryModel()
        if 'last_key' in d:
            o.last_key = d['last_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ParticipantForm import ParticipantForm


class AlipayFundWalletDepositorderCreateModel(object):

    def __init__(self):
        self._amount = None
        self._biz_scene = None
        self._effective_end_date = None
        self._expand_amount = None
        self._order_title = None
        self._out_biz_no = None
        self._payee_info = None
        self._platform = None
        self._product_code = None
        self._remark = None
        self._time_expire = None
        self._user_wallet_id = None
        self._valid_date = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def effective_end_date(self):
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, value):
        self._effective_end_date = value
    @property
    def expand_amount(self):
        return self._expand_amount

    @expand_amount.setter
    def expand_amount(self, value):
        self._expand_amount = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payee_info(self):
        return self._payee_info

    @payee_info.setter
    def payee_info(self, value):
        if isinstance(value, ParticipantForm):
            self._payee_info = value
        else:
            self._payee_info = ParticipantForm.from_alipay_dict(value)
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def time_expire(self):
        return self._time_expire

    @time_expire.setter
    def time_expire(self, value):
        self._time_expire = value
    @property
    def user_wallet_id(self):
        return self._user_wallet_id

    @user_wallet_id.setter
    def user_wallet_id(self, value):
        self._user_wallet_id = value
    @property
    def valid_date(self):
        return self._valid_date

    @valid_date.setter
    def valid_date(self, value):
        self._valid_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.effective_end_date:
            if hasattr(self.effective_end_date, 'to_alipay_dict'):
                params['effective_end_date'] = self.effective_end_date.to_alipay_dict()
            else:
                params['effective_end_date'] = self.effective_end_date
        if self.expand_amount:
            if hasattr(self.expand_amount, 'to_alipay_dict'):
                params['expand_amount'] = self.expand_amount.to_alipay_dict()
            else:
                params['expand_amount'] = self.expand_amount
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payee_info:
            if hasattr(self.payee_info, 'to_alipay_dict'):
                params['payee_info'] = self.payee_info.to_alipay_dict()
            else:
                params['payee_info'] = self.payee_info
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.time_expire:
            if hasattr(self.time_expire, 'to_alipay_dict'):
                params['time_expire'] = self.time_expire.to_alipay_dict()
            else:
                params['time_expire'] = self.time_expire
        if self.user_wallet_id:
            if hasattr(self.user_wallet_id, 'to_alipay_dict'):
                params['user_wallet_id'] = self.user_wallet_id.to_alipay_dict()
            else:
                params['user_wallet_id'] = self.user_wallet_id
        if self.valid_date:
            if hasattr(self.valid_date, 'to_alipay_dict'):
                params['valid_date'] = self.valid_date.to_alipay_dict()
            else:
                params['valid_date'] = self.valid_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundWalletDepositorderCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'effective_end_date' in d:
            o.effective_end_date = d['effective_end_date']
        if 'expand_amount' in d:
            o.expand_amount = d['expand_amount']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payee_info' in d:
            o.payee_info = d['payee_info']
        if 'platform' in d:
            o.platform = d['platform']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'remark' in d:
            o.remark = d['remark']
        if 'time_expire' in d:
            o.time_expire = d['time_expire']
        if 'user_wallet_id' in d:
            o.user_wallet_id = d['user_wallet_id']
        if 'valid_date' in d:
            o.valid_date = d['valid_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BailAuthOrderDTO import BailAuthOrderDTO
from alipay.aop.api.domain.StandardBailDTO import StandardBailDTO


class AlipayFundBailOrderBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundBailOrderBatchqueryResponse, self).__init__()
        self._bail_auth_list = None
        self._standard_bail_list = None

    @property
    def bail_auth_list(self):
        return self._bail_auth_list

    @bail_auth_list.setter
    def bail_auth_list(self, value):
        if isinstance(value, list):
            self._bail_auth_list = list()
            for i in value:
                if isinstance(i, BailAuthOrderDTO):
                    self._bail_auth_list.append(i)
                else:
                    self._bail_auth_list.append(BailAuthOrderDTO.from_alipay_dict(i))
    @property
    def standard_bail_list(self):
        return self._standard_bail_list

    @standard_bail_list.setter
    def standard_bail_list(self, value):
        if isinstance(value, list):
            self._standard_bail_list = list()
            for i in value:
                if isinstance(i, StandardBailDTO):
                    self._standard_bail_list.append(i)
                else:
                    self._standard_bail_list.append(StandardBailDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayFundBailOrderBatchqueryResponse, self).parse_response_content(response_content)
        if 'bail_auth_list' in response:
            self.bail_auth_list = response['bail_auth_list']
        if 'standard_bail_list' in response:
            self.standard_bail_list = response['standard_bail_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VehLimitDetailsResDTO(object):

    def __init__(self):
        self._isv_code = None
        self._lbs_city_code = None
        self._limit_area = None
        self._limit_rule_detail = None
        self._limit_rule_name = None
        self._limit_tail_num = None
        self._limit_time = None

    @property
    def isv_code(self):
        return self._isv_code

    @isv_code.setter
    def isv_code(self, value):
        self._isv_code = value
    @property
    def lbs_city_code(self):
        return self._lbs_city_code

    @lbs_city_code.setter
    def lbs_city_code(self, value):
        self._lbs_city_code = value
    @property
    def limit_area(self):
        return self._limit_area

    @limit_area.setter
    def limit_area(self, value):
        self._limit_area = value
    @property
    def limit_rule_detail(self):
        return self._limit_rule_detail

    @limit_rule_detail.setter
    def limit_rule_detail(self, value):
        self._limit_rule_detail = value
    @property
    def limit_rule_name(self):
        return self._limit_rule_name

    @limit_rule_name.setter
    def limit_rule_name(self, value):
        self._limit_rule_name = value
    @property
    def limit_tail_num(self):
        return self._limit_tail_num

    @limit_tail_num.setter
    def limit_tail_num(self, value):
        self._limit_tail_num = value
    @property
    def limit_time(self):
        return self._limit_time

    @limit_time.setter
    def limit_time(self, value):
        self._limit_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_code:
            if hasattr(self.isv_code, 'to_alipay_dict'):
                params['isv_code'] = self.isv_code.to_alipay_dict()
            else:
                params['isv_code'] = self.isv_code
        if self.lbs_city_code:
            if hasattr(self.lbs_city_code, 'to_alipay_dict'):
                params['lbs_city_code'] = self.lbs_city_code.to_alipay_dict()
            else:
                params['lbs_city_code'] = self.lbs_city_code
        if self.limit_area:
            if hasattr(self.limit_area, 'to_alipay_dict'):
                params['limit_area'] = self.limit_area.to_alipay_dict()
            else:
                params['limit_area'] = self.limit_area
        if self.limit_rule_detail:
            if hasattr(self.limit_rule_detail, 'to_alipay_dict'):
                params['limit_rule_detail'] = self.limit_rule_detail.to_alipay_dict()
            else:
                params['limit_rule_detail'] = self.limit_rule_detail
        if self.limit_rule_name:
            if hasattr(self.limit_rule_name, 'to_alipay_dict'):
                params['limit_rule_name'] = self.limit_rule_name.to_alipay_dict()
            else:
                params['limit_rule_name'] = self.limit_rule_name
        if self.limit_tail_num:
            if hasattr(self.limit_tail_num, 'to_alipay_dict'):
                params['limit_tail_num'] = self.limit_tail_num.to_alipay_dict()
            else:
                params['limit_tail_num'] = self.limit_tail_num
        if self.limit_time:
            if hasattr(self.limit_time, 'to_alipay_dict'):
                params['limit_time'] = self.limit_time.to_alipay_dict()
            else:
                params['limit_time'] = self.limit_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VehLimitDetailsResDTO()
        if 'isv_code' in d:
            o.isv_code = d['isv_code']
        if 'lbs_city_code' in d:
            o.lbs_city_code = d['lbs_city_code']
        if 'limit_area' in d:
            o.limit_area = d['limit_area']
        if 'limit_rule_detail' in d:
            o.limit_rule_detail = d['limit_rule_detail']
        if 'limit_rule_name' in d:
            o.limit_rule_name = d['limit_rule_name']
        if 'limit_tail_num' in d:
            o.limit_tail_num = d['limit_tail_num']
        if 'limit_time' in d:
            o.limit_time = d['limit_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ShopReportProgressInfo import ShopReportProgressInfo


class AlipayOverseasTravelShopReportCallbackModel(object):

    def __init__(self):
        self._data_version = None
        self._out_shop_id = None
        self._progress_info = None
        self._result_code = None
        self._result_message = None
        self._result_status = None

    @property
    def data_version(self):
        return self._data_version

    @data_version.setter
    def data_version(self, value):
        self._data_version = value
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def progress_info(self):
        return self._progress_info

    @progress_info.setter
    def progress_info(self, value):
        if isinstance(value, ShopReportProgressInfo):
            self._progress_info = value
        else:
            self._progress_info = ShopReportProgressInfo.from_alipay_dict(value)
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def result_status(self):
        return self._result_status

    @result_status.setter
    def result_status(self, value):
        self._result_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_version:
            if hasattr(self.data_version, 'to_alipay_dict'):
                params['data_version'] = self.data_version.to_alipay_dict()
            else:
                params['data_version'] = self.data_version
        if self.out_shop_id:
            if hasattr(self.out_shop_id, 'to_alipay_dict'):
                params['out_shop_id'] = self.out_shop_id.to_alipay_dict()
            else:
                params['out_shop_id'] = self.out_shop_id
        if self.progress_info:
            if hasattr(self.progress_info, 'to_alipay_dict'):
                params['progress_info'] = self.progress_info.to_alipay_dict()
            else:
                params['progress_info'] = self.progress_info
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.result_message:
            if hasattr(self.result_message, 'to_alipay_dict'):
                params['result_message'] = self.result_message.to_alipay_dict()
            else:
                params['result_message'] = self.result_message
        if self.result_status:
            if hasattr(self.result_status, 'to_alipay_dict'):
                params['result_status'] = self.result_status.to_alipay_dict()
            else:
                params['result_status'] = self.result_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelShopReportCallbackModel()
        if 'data_version' in d:
            o.data_version = d['data_version']
        if 'out_shop_id' in d:
            o.out_shop_id = d['out_shop_id']
        if 'progress_info' in d:
            o.progress_info = d['progress_info']
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'result_message' in d:
            o.result_message = d['result_message']
        if 'result_status' in d:
            o.result_status = d['result_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZftSubMerchantOrder(object):

    def __init__(self):
        self._app_pre_auth = None
        self._apply_time = None
        self._apply_type = None
        self._card_alias_no = None
        self._external_id = None
        self._face_pre_auth = None
        self._fk_audit = None
        self._fk_audit_memo = None
        self._is_face_limit = None
        self._kz_audit = None
        self._kz_audit_memo = None
        self._merchant_name = None
        self._order_id = None
        self._reason = None
        self._smid = None
        self._status = None
        self._sub_confirm = None

    @property
    def app_pre_auth(self):
        return self._app_pre_auth

    @app_pre_auth.setter
    def app_pre_auth(self, value):
        self._app_pre_auth = value
    @property
    def apply_time(self):
        return self._apply_time

    @apply_time.setter
    def apply_time(self, value):
        self._apply_time = value
    @property
    def apply_type(self):
        return self._apply_type

    @apply_type.setter
    def apply_type(self, value):
        self._apply_type = value
    @property
    def card_alias_no(self):
        return self._card_alias_no

    @card_alias_no.setter
    def card_alias_no(self, value):
        self._card_alias_no = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def face_pre_auth(self):
        return self._face_pre_auth

    @face_pre_auth.setter
    def face_pre_auth(self, value):
        self._face_pre_auth = value
    @property
    def fk_audit(self):
        return self._fk_audit

    @fk_audit.setter
    def fk_audit(self, value):
        self._fk_audit = value
    @property
    def fk_audit_memo(self):
        return self._fk_audit_memo

    @fk_audit_memo.setter
    def fk_audit_memo(self, value):
        self._fk_audit_memo = value
    @property
    def is_face_limit(self):
        return self._is_face_limit

    @is_face_limit.setter
    def is_face_limit(self, value):
        self._is_face_limit = value
    @property
    def kz_audit(self):
        return self._kz_audit

    @kz_audit.setter
    def kz_audit(self, value):
        self._kz_audit = value
    @property
    def kz_audit_memo(self):
        return self._kz_audit_memo

    @kz_audit_memo.setter
    def kz_audit_memo(self, value):
        self._kz_audit_memo = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_confirm(self):
        return self._sub_confirm

    @sub_confirm.setter
    def sub_confirm(self, value):
        self._sub_confirm = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_pre_auth:
            if hasattr(self.app_pre_auth, 'to_alipay_dict'):
                params['app_pre_auth'] = self.app_pre_auth.to_alipay_dict()
            else:
                params['app_pre_auth'] = self.app_pre_auth
        if self.apply_time:
            if hasattr(self.apply_time, 'to_alipay_dict'):
                params['apply_time'] = self.apply_time.to_alipay_dict()
            else:
                params['apply_time'] = self.apply_time
        if self.apply_type:
            if hasattr(self.apply_type, 'to_alipay_dict'):
                params['apply_type'] = self.apply_type.to_alipay_dict()
            else:
                params['apply_type'] = self.apply_type
        if self.card_alias_no:
            if hasattr(self.card_alias_no, 'to_alipay_dict'):
                params['card_alias_no'] = self.card_alias_no.to_alipay_dict()
            else:
                params['card_alias_no'] = self.card_alias_no
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.face_pre_auth:
            if hasattr(self.face_pre_auth, 'to_alipay_dict'):
                params['face_pre_auth'] = self.face_pre_auth.to_alipay_dict()
            else:
                params['face_pre_auth'] = self.face_pre_auth
        if self.fk_audit:
            if hasattr(self.fk_audit, 'to_alipay_dict'):
                params['fk_audit'] = self.fk_audit.to_alipay_dict()
            else:
                params['fk_audit'] = self.fk_audit
        if self.fk_audit_memo:
            if hasattr(self.fk_audit_memo, 'to_alipay_dict'):
                params['fk_audit_memo'] = self.fk_audit_memo.to_alipay_dict()
            else:
                params['fk_audit_memo'] = self.fk_audit_memo
        if self.is_face_limit:
            if hasattr(self.is_face_limit, 'to_alipay_dict'):
                params['is_face_limit'] = self.is_face_limit.to_alipay_dict()
            else:
                params['is_face_limit'] = self.is_face_limit
        if self.kz_audit:
            if hasattr(self.kz_audit, 'to_alipay_dict'):
                params['kz_audit'] = self.kz_audit.to_alipay_dict()
            else:
                params['kz_audit'] = self.kz_audit
        if self.kz_audit_memo:
            if hasattr(self.kz_audit_memo, 'to_alipay_dict'):
                params['kz_audit_memo'] = self.kz_audit_memo.to_alipay_dict()
            else:
                params['kz_audit_memo'] = self.kz_audit_memo
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_confirm:
            if hasattr(self.sub_confirm, 'to_alipay_dict'):
                params['sub_confirm'] = self.sub_confirm.to_alipay_dict()
            else:
                params['sub_confirm'] = self.sub_confirm
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZftSubMerchantOrder()
        if 'app_pre_auth' in d:
            o.app_pre_auth = d['app_pre_auth']
        if 'apply_time' in d:
            o.apply_time = d['apply_time']
        if 'apply_type' in d:
            o.apply_type = d['apply_type']
        if 'card_alias_no' in d:
            o.card_alias_no = d['card_alias_no']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'face_pre_auth' in d:
            o.face_pre_auth = d['face_pre_auth']
        if 'fk_audit' in d:
            o.fk_audit = d['fk_audit']
        if 'fk_audit_memo' in d:
            o.fk_audit_memo = d['fk_audit_memo']
        if 'is_face_limit' in d:
            o.is_face_limit = d['is_face_limit']
        if 'kz_audit' in d:
            o.kz_audit = d['kz_audit']
        if 'kz_audit_memo' in d:
            o.kz_audit_memo = d['kz_audit_memo']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'reason' in d:
            o.reason = d['reason']
        if 'smid' in d:
            o.smid = d['smid']
        if 'status' in d:
            o.status = d['status']
        if 'sub_confirm' in d:
            o.sub_confirm = d['sub_confirm']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RoyaltyEntity(object):

    def __init__(self):
        self._account = None
        self._account_open_id = None
        self._bind_login_name = None
        self._login_name = None
        self._memo = None
        self._name = None
        self._type = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def account_open_id(self):
        return self._account_open_id

    @account_open_id.setter
    def account_open_id(self, value):
        self._account_open_id = value
    @property
    def bind_login_name(self):
        return self._bind_login_name

    @bind_login_name.setter
    def bind_login_name(self, value):
        self._bind_login_name = value
    @property
    def login_name(self):
        return self._login_name

    @login_name.setter
    def login_name(self, value):
        self._login_name = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.account_open_id:
            if hasattr(self.account_open_id, 'to_alipay_dict'):
                params['account_open_id'] = self.account_open_id.to_alipay_dict()
            else:
                params['account_open_id'] = self.account_open_id
        if self.bind_login_name:
            if hasattr(self.bind_login_name, 'to_alipay_dict'):
                params['bind_login_name'] = self.bind_login_name.to_alipay_dict()
            else:
                params['bind_login_name'] = self.bind_login_name
        if self.login_name:
            if hasattr(self.login_name, 'to_alipay_dict'):
                params['login_name'] = self.login_name.to_alipay_dict()
            else:
                params['login_name'] = self.login_name
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RoyaltyEntity()
        if 'account' in d:
            o.account = d['account']
        if 'account_open_id' in d:
            o.account_open_id = d['account_open_id']
        if 'bind_login_name' in d:
            o.bind_login_name = d['bind_login_name']
        if 'login_name' in d:
            o.login_name = d['login_name']
        if 'memo' in d:
            o.memo = d['memo']
        if 'name' in d:
            o.name = d['name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasTransferPaymentQueryModel(object):

    def __init__(self):
        self._pass_through_info = None
        self._payer_agent_id = None
        self._transfer_request_id = None

    @property
    def pass_through_info(self):
        return self._pass_through_info

    @pass_through_info.setter
    def pass_through_info(self, value):
        self._pass_through_info = value
    @property
    def payer_agent_id(self):
        return self._payer_agent_id

    @payer_agent_id.setter
    def payer_agent_id(self, value):
        self._payer_agent_id = value
    @property
    def transfer_request_id(self):
        return self._transfer_request_id

    @transfer_request_id.setter
    def transfer_request_id(self, value):
        self._transfer_request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.pass_through_info:
            if hasattr(self.pass_through_info, 'to_alipay_dict'):
                params['pass_through_info'] = self.pass_through_info.to_alipay_dict()
            else:
                params['pass_through_info'] = self.pass_through_info
        if self.payer_agent_id:
            if hasattr(self.payer_agent_id, 'to_alipay_dict'):
                params['payer_agent_id'] = self.payer_agent_id.to_alipay_dict()
            else:
                params['payer_agent_id'] = self.payer_agent_id
        if self.transfer_request_id:
            if hasattr(self.transfer_request_id, 'to_alipay_dict'):
                params['transfer_request_id'] = self.transfer_request_id.to_alipay_dict()
            else:
                params['transfer_request_id'] = self.transfer_request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTransferPaymentQueryModel()
        if 'pass_through_info' in d:
            o.pass_through_info = d['pass_through_info']
        if 'payer_agent_id' in d:
            o.payer_agent_id = d['payer_agent_id']
        if 'transfer_request_id' in d:
            o.transfer_request_id = d['transfer_request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppPdeductSignValidateModel(object):

    def __init__(self):
        self._agent_channel = None
        self._agent_code = None
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._deduct_type = None
        self._extend_field = None
        self._notify_config = None
        self._open_id = None
        self._out_agreement_id = None
        self._owner_name = None
        self._pay_config = None
        self._pid = None
        self._sign_expire_date = None
        self._sub_biz_type = None
        self._user_id = None

    @property
    def agent_channel(self):
        return self._agent_channel

    @agent_channel.setter
    def agent_channel(self, value):
        self._agent_channel = value
    @property
    def agent_code(self):
        return self._agent_code

    @agent_code.setter
    def agent_code(self, value):
        self._agent_code = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def deduct_type(self):
        return self._deduct_type

    @deduct_type.setter
    def deduct_type(self, value):
        self._deduct_type = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def notify_config(self):
        return self._notify_config

    @notify_config.setter
    def notify_config(self, value):
        self._notify_config = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_agreement_id(self):
        return self._out_agreement_id

    @out_agreement_id.setter
    def out_agreement_id(self, value):
        self._out_agreement_id = value
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def pay_config(self):
        return self._pay_config

    @pay_config.setter
    def pay_config(self, value):
        self._pay_config = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def sign_expire_date(self):
        return self._sign_expire_date

    @sign_expire_date.setter
    def sign_expire_date(self, value):
        self._sign_expire_date = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_channel:
            if hasattr(self.agent_channel, 'to_alipay_dict'):
                params['agent_channel'] = self.agent_channel.to_alipay_dict()
            else:
                params['agent_channel'] = self.agent_channel
        if self.agent_code:
            if hasattr(self.agent_code, 'to_alipay_dict'):
                params['agent_code'] = self.agent_code.to_alipay_dict()
            else:
                params['agent_code'] = self.agent_code
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.deduct_type:
            if hasattr(self.deduct_type, 'to_alipay_dict'):
                params['deduct_type'] = self.deduct_type.to_alipay_dict()
            else:
                params['deduct_type'] = self.deduct_type
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        if self.notify_config:
            if hasattr(self.notify_config, 'to_alipay_dict'):
                params['notify_config'] = self.notify_config.to_alipay_dict()
            else:
                params['notify_config'] = self.notify_config
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_agreement_id:
            if hasattr(self.out_agreement_id, 'to_alipay_dict'):
                params['out_agreement_id'] = self.out_agreement_id.to_alipay_dict()
            else:
                params['out_agreement_id'] = self.out_agreement_id
        if self.owner_name:
            if hasattr(self.owner_name, 'to_alipay_dict'):
                params['owner_name'] = self.owner_name.to_alipay_dict()
            else:
                params['owner_name'] = self.owner_name
        if self.pay_config:
            if hasattr(self.pay_config, 'to_alipay_dict'):
                params['pay_config'] = self.pay_config.to_alipay_dict()
            else:
                params['pay_config'] = self.pay_config
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.sign_expire_date:
            if hasattr(self.sign_expire_date, 'to_alipay_dict'):
                params['sign_expire_date'] = self.sign_expire_date.to_alipay_dict()
            else:
                params['sign_expire_date'] = self.sign_expire_date
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppPdeductSignValidateModel()
        if 'agent_channel' in d:
            o.agent_channel = d['agent_channel']
        if 'agent_code' in d:
            o.agent_code = d['agent_code']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'deduct_type' in d:
            o.deduct_type = d['deduct_type']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        if 'notify_config' in d:
            o.notify_config = d['notify_config']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_agreement_id' in d:
            o.out_agreement_id = d['out_agreement_id']
        if 'owner_name' in d:
            o.owner_name = d['owner_name']
        if 'pay_config' in d:
            o.pay_config = d['pay_config']
        if 'pid' in d:
            o.pid = d['pid']
        if 'sign_expire_date' in d:
            o.sign_expire_date = d['sign_expire_date']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


